@@ -75,7 +75,6 @@ private Q_SLOTS:
         QCOMPARE(dialog.selectedNameFilter(), selectNameFilter);
     }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
     void testSelectedMimeTypeFilter_data()
     {
         QTest::addColumn<QStringList>("mimeTypeFilters");
@@ -121,9 +120,6 @@ private Q_SLOTS:
         QCOMPARE(dialog.selectedMimeTypeFilter(), QStringLiteral("application/json"));
     }
 
-#endif
-
-
     void testSetDirectory()
     {
         QFileDialog dialog;
@@ -192,7 +188,7 @@ private Q_SLOTS:
             KFileWidget *fw = findFileWidget();
             QVERIFY(fw);
             // real show() is delayed to next event.
-            QTest::qWaitForWindowExposed(fw->window());
+            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
             KDirOperator *op = fw->dirOperator();
             QCOMPARE(fileViewToString(op->viewMode()), fileViewToString(KFile::Tree));
             fw->setViewMode(KFile::Simple);
@@ -222,7 +218,7 @@ private Q_SLOTS:
             KFileWidget *fw = findFileWidget();
             QVERIFY(fw);
             // real show() is delayed to next event.
-            QTest::qWaitForWindowExposed(fw->window());
+            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
             QCOMPARE(fw->isVisible(), true);
             fw->slotCancel();
         }
@@ -237,7 +233,7 @@ private Q_SLOTS:
             KFileWidget *fw = findFileWidget();
             QVERIFY(fw);
             // real show() is delayed to next event.
-            QTest::qWaitForWindowExposed(fw->window());
+            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
             QCOMPARE(fw->isVisible(), true);
             fw->slotCancel();
         }
@@ -253,7 +249,7 @@ private Q_SLOTS:
             KFileWidget *fw = findFileWidget();
             QVERIFY(fw);
             // real show() is delayed to next event.
-            QTest::qWaitForWindowExposed(fw->window());
+            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
             QCOMPARE(fw->isVisible(), true);
             fw->slotCancel();
         }
@@ -268,7 +264,7 @@ private Q_SLOTS:
             KFileWidget *fw = findFileWidget();
             QVERIFY(fw);
             // real show() is delayed to next event.
-            QTest::qWaitForWindowExposed(fw->window());
+            QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
             QCOMPARE(fw->isVisible(), true);
             fw->slotCancel();
         }
@@ -328,7 +324,7 @@ private Q_SLOTS:
         
         KFileWidget *fw = findFileWidget();
         QVERIFY(fw);
-        QTest::qWaitForWindowExposed(fw->window());
+        QVERIFY(QTest::qWaitForWindowExposed(fw->window()));
         QCOMPARE(fw->isVisible(), true);
         
         bool timerRun = false;
@@ -338,7 +334,7 @@ private Q_SLOTS:
             QDialog *msgbox = findMessageBox();
             if (msgbox)
             {
-                QTest::qWaitForWindowExposed(msgbox);
+                QVERIFY(QTest::qWaitForWindowExposed(msgbox));
                 QCOMPARE(msgbox->isVisible(), true);
                 msgbox->close();
                 QVERIFY(messageBoxExpected);
